@@ -31,6 +31,6 @@ static UntypedResponse cmd_debug_prof_dump(Client*, const json_ref&) {
               .c_str()));
   return resp;
 }
-W_CMD_REG("debug-prof-dump", cmd_debug_prof_dump, CMD_DAEMON, NULL);
+W_CMD_REG("debug-prof-dump", cmd_debug_prof_dump, CMD_DAEMON, nullptr);
 
 #endif
