@@ -7,9 +7,11 @@
 
 #include <folly/MapUtil.h>
 #include "watchman/Client.h"
+#include "watchman/ClientContext.h"
 #include "watchman/Errors.h"
 #include "watchman/Logging.h"
 #include "watchman/MapUtil.h"
+#include "watchman/ProcessUtil.h"
 #include "watchman/QueryableView.h"
 #include "watchman/query/Query.h"
 #include "watchman/query/eval.h"
@@ -129,7 +131,8 @@ void ClientSubscription::processSubscription() {
           " got: ",
           exc.what(),
           ".  Cancel watch\n");
-      root->cancel();
+      root->cancel(
+          fmt::format("Error processing subscriptions: {}", exc.what()));
     } else {
       throw;
     }
@@ -380,7 +383,8 @@ static UntypedResponse cmd_flush_subscriptions(
     }
   }
 
-  root->syncToNow(std::chrono::milliseconds(sync_timeout));
+  root->syncToNow(
+      std::chrono::milliseconds(sync_timeout), client->getClientInfo());
 
   UntypedResponse resp;
   std::vector<json_ref> synced;
@@ -490,7 +494,11 @@ static UntypedResponse cmd_subscribe(Client* clientbase, const json_ref& args) {
   json_ref query_spec = args.at(3);
 
   auto query = parseQuery(root, query_spec);
-  query->clientPid = client->stm ? client->stm->getPeerProcessID() : 0;
+  auto clientPid = client->stm ? client->stm->getPeerProcessID() : 0;
+  query->clientInfo.clientPid = clientPid;
+  query->clientInfo.clientInfo = clientPid
+      ? std::make_optional(lookupProcessInfo(clientPid))
+      : std::nullopt;
   query->subscriptionName = json_to_w_string(jname);
 
   auto defer_list = query_spec.get_optional("defer");
@@ -508,10 +516,27 @@ static UntypedResponse cmd_subscribe(Client* clientbase, const json_ref& args) {
   const std::vector<json_ref>* drop_array =
       drop_list ? &drop_list->array() : nullptr;
 
+  UntypedResponse resp;
+
+  auto sub_name = json_to_w_string(jname);
+
+  // Check for duplicate subscription names. We do this early because
+  // constructing a ClientSubscription with a duplicate name isn't safe.
+  if (mapContainsAny(client->subscriptions, sub_name)) {
+    if (root->config.getBool("enforce_unique_subscription_names", false)) {
+      throw ErrorResponse("subscription name '{}' is not unique", sub_name);
+    }
+    log(ERR, "clobbering existing subscription '", sub_name, "'\n");
+    resp.set(
+        "warning",
+        w_string_to_json(w_string::format(
+            "subscription name '{}' is not unique", sub_name)));
+  }
+
   auto sub =
       std::make_shared<ClientSubscription>(root, client->shared_from_this());
 
-  sub->name = json_to_w_string(jname);
+  sub->name = std::move(sub_name);
   sub->query = query;
 
   auto defer = query_spec.get_default("defer_vcs", json_true());
@@ -573,7 +598,6 @@ static UntypedResponse cmd_subscribe(Client* clientbase, const json_ref& args) {
 
   client->subscriptions[sub->name] = sub;
 
-  UntypedResponse resp;
   resp.set("subscribe", json_ref(jname));
 
   add_root_warnings_to_response(resp, root);
