@@ -74,8 +74,8 @@
 #include <folly/Executor.h>
 #include <folly/Optional.h>
 #include <folly/Try.h>
-#include <folly/dynamic.h>
 #include <folly/futures/Future.h>
+#include <folly/json/dynamic.h>
 
 namespace watchman {
 
