@@ -9,8 +9,10 @@
 
 import os
 import random
+import re
 import stat
 import string
+import subprocess
 import sys
 import time
 import unittest
@@ -266,6 +268,25 @@ class TestSockPerms(unittest.TestCase):
         self.assertFileGID(instance.user_dir, gid)
         self.assertFileGID(instance.sock_file, gid)
 
+    def test_sock_access_via_acl(self) -> None:
+        gid = self._get_custom_gid()
+        group = grp.getgrgid(gid)
+        instance = self._new_instance({"secondary_sock_group": group.gr_name})
+        instance.start()
+        instance.stop()
+
+        self.assertACL(instance.user_dir, group, f"group:{group.gr_name}:r-x")
+        self.assertACL(instance.sock_file, group, f"group:{group.gr_name}:rw-")
+
+    def test_sock_access_via_acl_user_not_in_sock_group(self) -> None:
+        group = self._get_non_member_group()
+        instance = self._new_instance({"secondary_sock_group": group.gr_name})
+        instance.start()
+        instance.stop()
+
+        self.assertACL(instance.user_dir, group, f"group:{group.gr_name}:r-x")
+        self.assertACL(instance.sock_file, group, f"group:{group.gr_name}:rw-")
+
     def assertFileMode(self, f, mode) -> None:
         st = os.lstat(f)
         self.assertEqual(stat.S_IMODE(st.st_mode), mode)
@@ -273,3 +294,14 @@ class TestSockPerms(unittest.TestCase):
     def assertFileGID(self, f, gid) -> None:
         st = os.lstat(f)
         self.assertEqual(st.st_gid, gid)
+
+    def assertACL(self, f, group, expected_regex) -> None:
+        getfacl_result = subprocess.run(
+            ["/usr/bin/getfacl", f], capture_output=True, text=True, check=True
+        ).stdout
+
+        group_pattern = re.compile(expected_regex)
+        self.assertIsNotNone(
+            group_pattern.search(getfacl_result),
+            f"Group '{group.gr_name}' does not have expected permissions {expected_regex}, acl result:\n {getfacl_result}",
+        )
