@@ -13,6 +13,7 @@
 #include <folly/String.h>
 #include <folly/init/Init.h>
 #include <folly/net/NetworkSocket.h>
+#include <folly/portability/Fcntl.h>
 #include <folly/system/Shell.h>
 
 #include <stdio.h>
@@ -33,6 +34,7 @@
 #include "watchman/ThreadPool.h"
 #include "watchman/UserDir.h"
 #include "watchman/WatchmanConfig.h"
+#include "watchman/XattrUtils.h"
 #include "watchman/fs/DirHandle.h"
 #include "watchman/fs/FileSystem.h"
 #include "watchman/listener.h"
@@ -138,18 +140,19 @@ std::optional<std::string> detect_starting_command(pid_t ppid) {
 #endif
 
   // redirect std{in,out,err}
-  int fd = ::open("/dev/null", O_RDONLY);
+  int fd = folly::fileops::open("/dev/null", O_RDONLY);
   if (fd != -1) {
     ignore_result(::dup2(fd, STDIN_FILENO));
-    ::close(fd);
+    folly::fileops::close(fd);
   }
 
   if (logging::log_name != "-") {
-    fd = open(logging::log_name.c_str(), O_WRONLY | O_APPEND | O_CREAT, 0600);
+    fd = folly::fileops::open(
+        logging::log_name.c_str(), O_WRONLY | O_APPEND | O_CREAT, 0600);
     if (fd != -1) {
       ignore_result(::dup2(fd, STDOUT_FILENO));
       ignore_result(::dup2(fd, STDERR_FILENO));
-      ::close(fd);
+      folly::fileops::close(fd);
     }
   }
 
@@ -259,7 +262,7 @@ static void close_random_fds() {
   }
 
   for (max_fd = open_max; max_fd > STDERR_FILENO; --max_fd) {
-    close(max_fd);
+    folly::fileops::close(max_fd);
   }
 #endif
 }
@@ -643,6 +646,8 @@ static void verify_dir_ownership(const std::string& state_dir) {
   uid_t euid = geteuid();
   // TODO: also allow a gid to be specified here
   const char* sock_group_name = cfg_get_string("sock_group", nullptr);
+  const char* secondary_sock_group =
+      cfg_get_string("secondary_sock_group", nullptr);
   // S_ISGID is set so that files inside this directory inherit the group
   // name
   mode_t dir_perms =
@@ -708,6 +713,26 @@ static void verify_dir_ownership(const std::string& state_dir) {
     }
   }
 
+#ifdef __linux__
+  // Allow setting an ACL on the state_dir, this method does not require the
+  // owner to be a member of the target group.
+  if (secondary_sock_group) {
+    // TODO: pass mode_t dir_perms (from earlier in this function) to
+    // setSecondaryGroupACL instead of using three booleans
+    if (!watchman::setSecondaryGroupACL(
+            state_dir.c_str(),
+            secondary_sock_group,
+            true /* read bits */,
+            false /* write bits */,
+            true /* execute bits */)) {
+      ret = 1;
+      goto bail;
+    }
+  }
+#else
+  (void)secondary_sock_group;
+#endif
+
   // Depending on group and world accessibility, change permissions on the
   // directory. We can't leave the directory open and set permissions on the
   // socket because not all POSIX systems respect permissions on UNIX domain
