@@ -606,16 +606,36 @@ static PyObject* bser_load(PyObject* self, PyObject* args, PyObject* kw) {
 
 // clang-format off
 static PyMethodDef bser_methods[] = {
-  {"loads", (PyCFunction)bser_loads, METH_VARARGS | METH_KEYWORDS,
-   "Deserialize string."},
-  {"load", (PyCFunction)bser_load, METH_VARARGS | METH_KEYWORDS,
-   "Deserialize a file object"},
-  {"pdu_info", (PyCFunction)bser_pdu_info, METH_VARARGS,
-   "Extract PDU information."},
-  {"pdu_len", (PyCFunction)bser_pdu_len, METH_VARARGS,
-   "Extract total PDU length."},
-  {"dumps",  (PyCFunction)bser_dumps, METH_VARARGS | METH_KEYWORDS,
-   "Serialize string."},
+  {
+    "loads",
+    (void *)(PyCFunctionWithKeywords)bser_loads,
+    METH_VARARGS | METH_KEYWORDS,
+    "Deserialize string."
+  },
+  {
+    "load",
+    (void *)(PyCFunctionWithKeywords)bser_load,
+    METH_VARARGS | METH_KEYWORDS,
+    "Deserialize a file object"
+  },
+  {
+    "pdu_info",
+    (PyCFunction)bser_pdu_info,
+    METH_VARARGS,
+    "Extract PDU information."
+  },
+  {
+    "pdu_len",
+    (PyCFunction)bser_pdu_len,
+    METH_VARARGS,
+    "Extract total PDU length."
+  },
+  {
+    "dumps",
+    (void *)(PyCFunctionWithKeywords)bser_dumps,
+    METH_VARARGS | METH_KEYWORDS,
+    "Serialize string."
+  },
   {NULL, NULL, 0, NULL}
 };
 
