@@ -12,10 +12,7 @@
 #include "watchman/query/GlobTree.h"
 #include "watchman/query/Query.h"
 #include "watchman/query/QueryContext.h"
-#include "watchman/query/eval.h"
 #include "watchman/thirdparty/wildmatch/wildmatch.h"
-#include "watchman/watchman_dir.h"
-#include "watchman/watchman_file.h"
 
 using std::make_unique;
 
