@@ -186,6 +186,14 @@ class NameExpr : public QueryExpr {
   ReturnOnlyFiles listOnlyFiles() const override {
     return ReturnOnlyFiles::Unrelated;
   }
+
+  SimpleSuffixType evaluateSimpleSuffix() const override {
+    return SimpleSuffixType::Excluded;
+  }
+
+  std::vector<std::string> getSuffixQueryGlobPatterns() const override {
+    return std::vector<std::string>{};
+  }
 };
 
 W_TERM_PARSER(name, NameExpr::parseName);
