@@ -100,6 +100,19 @@ class SuffixExpr : public QueryExpr {
   ReturnOnlyFiles listOnlyFiles() const override {
     return ReturnOnlyFiles::Unrelated;
   }
+
+  SimpleSuffixType evaluateSimpleSuffix() const override {
+    return SimpleSuffixType::Suffix;
+  }
+
+  std::vector<std::string> getSuffixQueryGlobPatterns() const override {
+    std::vector<std::string> patterns;
+    for (const auto& suffix : suffixSet_) {
+      patterns.push_back("**/*." + suffix.string());
+    }
+
+    return patterns;
+  }
 };
 W_TERM_PARSER(suffix, SuffixExpr::parse);
 W_CAP_REG("suffix-set")
