@@ -119,6 +119,17 @@ class TypeExpr : public QueryExpr {
     }
     return ReturnOnlyFiles::Yes;
   }
+
+  SimpleSuffixType evaluateSimpleSuffix() const override {
+    if (arg == 'f') {
+      return SimpleSuffixType::Type;
+    }
+    return SimpleSuffixType::Excluded;
+  }
+
+  std::vector<std::string> getSuffixQueryGlobPatterns() const override {
+    return std::vector<std::string>{};
+  }
 };
 W_TERM_PARSER(type, TypeExpr::parse);
 
