@@ -7,13 +7,13 @@
 
 use std::path::PathBuf;
 
-use structopt::StructOpt;
+use clap::Parser;
 use watchman_client::prelude::*;
 
-#[derive(Debug, StructOpt)]
-#[structopt(about = "Exercise the state-enter and state-leave commands")]
-struct Opt {
-    #[structopt(default_value = ".")]
+/// Exercise the state-enter and state-leave commands
+#[derive(Debug, Parser)]
+struct Cli {
+    #[arg(default_value = ".")]
     path: PathBuf,
 }
 
@@ -28,7 +28,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 }
 
 async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    let opt = Opt::from_args();
+    let opt = Cli::parse();
     let client = Connector::new().connect().await?;
     let resolved = client
         .resolve_root(CanonicalPath::canonicalize(opt.path)?)
